==> vtiger-4.0.r1.tbz: www/vtiger/modules/Dashboard/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Dashboard/language/en_us.lang.php,v 1.4 2005/01/25 06:01:38 jack Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_SALES_STAGE_FORM_TITLE'=>'Pipeline By Sales Stage',
'LBL_SALES_STAGE_FORM_DESC'=>'Shows cumulative opportunity amounts by selected sales stages for selected users where the expected closed date is within the specificed date range.',
'LBL_MONTH_BY_OUTCOME'=>'Pipeline By Month By Outcome',
'LBL_MONTH_BY_OUTCOME_DESC'=>'Shows cumulative opportunity amounts by month by outcome for selected users where the expected closed date is within the specificed date range.  Outcome is based on whether the sales stage is Closed Won, Closed Lost or any other value.',
'LBL_LEAD_SOURCE_FORM_TITLE'=>'All Opportunities By Lead Source',
'LBL_LEAD_SOURCE_FORM_DESC'=>'Shows cumulative opportunity amounts by selected lead source for selected users.',
'LBL_LEAD_SOURCE_BY_OUTCOME'=>'All Opportunities By Lead Source By Outcome',
'LBL_LEAD_SOURCE_BY_OUTCOME_DESC'=>'Shows cumulative opportunity amounts by selected lead source by outcome for selected users where the expected closed date is within the specificed date range.  Outcome is based on whether the sales stage is Closed Won, Closed Lost or any other value.',
'LBL_PIPELINE_FORM_TITLE_DESC'=>'Shows cumulative amounts by selected sales stages for your opportunities where the expected closed date is within the specificed date range.',
'LBL_DATE_RANGE'=>'Date range is',
'LBL_DATE_RANGE_TO'=>'to',
'ERR_NO_OPPS'=>'Please create some Opportunities to see Opportunity graphs.',
'LBL_TOTAL_PIPELINE'=>'Pipeline total is ',
'LBL_ALL_OPPORTUNITIES'=>'Total amount of all opportunities is ',
'LBL_OPP_SIZE'=>'Opportunity size in $1K',
'NTC_NO_LEGENDS'=>'None',
'LBL_LEAD_SOURCE_OTHER'=>'Other',
'LBL_EDIT'=>'Edit',
'LBL_REFRESH'=>'Refresh',
'LBL_CREATED_ON'=>'Last run on ',
'LBL_OPPS_IN_STAGE'=>'opportunities where sales stage is',
'LBL_OPPS_IN_LEAD_SOURCE'=>'opportunities where lead source is',
'LBL_OPPS_OUTCOME'=>'opportunities where outcome is',
'LBL_USERS'=>'Users:',
'LBL_SALES_STAGES'=>'Sales Stages:',
'LBL_LEAD_SOURCES'=>'Lead Sources:',
'LBL_DATE_START'=>'Begin Date:',
'LBL_DATE_END'=>'End Date:',

);

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/Dashboard/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Dashboard/language/en_us.lang.php,v 1.4 2005/01/25 06:01:38 jack Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_SALES_STAGE_FORM_TITLE'=>'Pipeline By Sales Stage',
'LBL_SALES_STAGE_FORM_DESC'=>'Shows cumulative opportunity amounts by selected sales stages for selected users where the expected closed date is within the specificed date range.',
'LBL_MONTH_BY_OUTCOME'=>'Pipeline By Month By Outcome',
'LBL_MONTH_BY_OUTCOME_DESC'=>'Shows cumulative opportunity amounts by month by outcome for selected users where the expected closed date is within the specificed date range.  Outcome is based on whether the sales stage is Closed Won, Closed Lost or any other value.',
'LBL_LEAD_SOURCE_FORM_TITLE'=>'All Opportunities By Lead Source',
'LBL_LEAD_SOURCE_FORM_DESC'=>'Shows cumulative opportunity amounts by selected lead source for selected users.',
'LBL_LEAD_SOURCE_BY_OUTCOME'=>'All Opportunities By Lead Source By Outcome',
'LBL_LEAD_SOURCE_BY_OUTCOME_DESC'=>'Shows cumulative opportunity amounts by selected lead source by outcome for selected users where the expected closed date is within the specificed date range.  Outcome is based on whether the sales stage is Closed Won, Closed Lost or any other value.',
'LBL_PIPELINE_FORM_TITLE_DESC'=>'Shows cumulative amounts by selected sales stages for your opportunities where the expected closed date is within the specificed date range.',
'LBL_DATE_RANGE'=>'Date range is',
'LBL_DATE_RANGE_TO'=>'to',
'ERR_NO_OPPS'=>'Please create some Opportunities to see Opportunity graphs.',
'LBL_TOTAL_PIPELINE'=>'Pipeline total is ',
'LBL_ALL_OPPORTUNITIES'=>'Total amount of all opportunities is ',
'LBL_OPP_SIZE'=>'Opportunity size in ',
'LBL_OPP_SIZE_VALUE'=>'1K',
'NTC_NO_LEGENDS'=>'None',
'LBL_LEAD_SOURCE_OTHER'=>'Other',
'LBL_EDIT'=>'Edit',
'LBL_REFRESH'=>'Refresh',
'LBL_CREATED_ON'=>'Last run on ',
'LBL_OPPS_IN_STAGE'=>'opportunities where sales stage is',
'LBL_OPPS_IN_LEAD_SOURCE'=>'opportunities where lead source is',
'LBL_OPPS_OUTCOME'=>'opportunities where outcome is',
'LBL_USERS'=>'Users:',
'LBL_SALES_STAGES'=>'Sales Stages:',
'LBL_LEAD_SOURCES'=>'Lead Sources:',
'LBL_DATE_START'=>'Begin Date:',
'LBL_DATE_END'=>'End Date:',

);

?>
